@@ -50,26 +50,28 @@ def stock_price_prediction():
 
 
 def get_wf_json(code=13):
-    url = f"https://www.jma.go.jp/bosai/forecast/data/forecast/{code}0000.json"
+    url = f"https://www.jma.go.jp/bosai/forecast/data/forecast/{code:02}0000.json"
     resp = requests.get(url)
     d = loads(resp.text)
     return d
 
 
 
-def pp():
+def pp(code=13):
     """
-    東京の直近の降水確率を返す
+    codeにある地域(デフォルトは東京)の
+    直近の降水確率を返す
     """
-    d = get_wf_json()
+    d = get_wf_json(code)
     return int(d[0]["timeSeries"][1]["areas"][0]["pops"][0])
 
 
-def temp():
+def temp(code=13):
     """
-    東京の直近の気温予測を返す
+    codeにある地域(デフォルトは東京)の
+    直近の気温予測を返す
     """
-    d = get_wf_json()
+    d = get_wf_json(code)
     c = int(d[0]["timeSeries"][2]["areas"][0]["temps"][0])
     return int(1.8*c+32)
 
@@ -83,7 +85,7 @@ def f2c(f):
 
 def ppl(code=13):
     """
-    東京の直近の降水確率を返す
+    codeにある地域(デフォルトは東京)の直近の降水確率を返す
     6時間ごと，7つ
     """
     d = get_wf_json(code)
