@@ -19,6 +19,16 @@ def show_board(gl):
             c = cell_tmpl.format(n, "human", "O")
             cell[gl[f"p{n}"]-1] = c
 
+    if "c" in gl:
+        for n, pl in enumerate(gl["c"]):
+            c = cell_tmpl.format(n, "pc", "X")
+            cell[pl-1] = c
+
+    if "p" in gl:
+        for n, pl in enumerate(gl["p"]):
+            c = cell_tmpl.format(n, "human", "O")
+            cell[pl-1] = c
+
     html_body = CSS
     html_body += FRAME.format(cell)
     display(HTML(html_body))
